@@ -2,13 +2,13 @@ from typing import Optional
 from datetime import datetime
 
 from airflow.models import BaseOperator, BaseOperatorLink
-from airflow.contrib.operators.bigquery_operator import (
-    BigQueryOperator,
+from airflow.providers.google.cloud.operators.bigquery import (
+    BigQueryExecuteQueryOperator,
     BigQueryCreateEmptyTableOperator,
 )
 
-from airflow.utils.decorators import apply_defaults
-from airflow.contrib.hooks.bigquery_hook import BigQueryHook
+# from airflow.utils.decorators import apply_defaults
+from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
 
 from airflow.exceptions import AirflowException
 
@@ -22,7 +22,7 @@ from gcp_airflow_foundations.base_class.hds_table_config import HdsTableConfig
 from gcp_airflow_foundations.enums.ingestion_type import IngestionType
 
 
-class MergeBigQueryHDS(BigQueryOperator):
+class MergeBigQueryHDS(BigQueryExecuteQueryOperator):
     """
     Merges data into a BigQuery HDS table.
 
@@ -56,13 +56,14 @@ class MergeBigQueryHDS(BigQueryOperator):
 
     template_fields = ("stg_table_name", "data_table_name", "stg_dataset_name")
 
-    @apply_defaults
+    # @apply_defaults
     def __init__(
         self,
         *,
         project_id: str,
         stg_table_name: str,
         data_table_name: str,
+        dag_table_id: str,
         stg_dataset_name: str,
         data_dataset_name: str,
         surrogate_keys: [str],
@@ -91,6 +92,7 @@ class MergeBigQueryHDS(BigQueryOperator):
         self.project_id = project_id
         self.stg_table_name = stg_table_name
         self.data_table_name = data_table_name
+        self.dag_table_id = dag_table_id
         self.stg_dataset_name = stg_dataset_name
         self.data_dataset_name = data_dataset_name
         self.surrogate_keys = surrogate_keys
@@ -106,7 +108,7 @@ class MergeBigQueryHDS(BigQueryOperator):
     def pre_execute(self, context) -> None:
         if not self.columns:
             staging_columns = self.xcom_pull(
-                context=context, task_ids="schema_parsing"
+                context=context, task_ids=f"{self.dag_table_id}.schema_parsing"
             )["source_table_columns"]
         else:
             staging_columns = self.columns
