@@ -1,12 +1,12 @@
 from typing import Optional
 
 from airflow.models import BaseOperator, BaseOperatorLink
-from airflow.contrib.operators.bigquery_operator import (
-    BigQueryOperator,
+from airflow.providers.google.cloud.operators.bigquery import (
+    BigQueryExecuteQueryOperator,
     BigQueryCreateEmptyTableOperator,
 )
 
-from airflow.utils.decorators import apply_defaults
+# from airflow.utils.decorators import apply_defaults
 from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
 
 from airflow.exceptions import AirflowException
@@ -36,12 +36,13 @@ class MigrateSchema(BaseOperator):
     :type gcp_conn_id: str
     """
 
-    @apply_defaults
+    # @apply_defaults
     def __init__(
         self,
         *,
         dataset_id,
         table_id,
+        dag_table_id,
         project_id,
         new_schema_fields=None,
         gcp_conn_id="google_cloud_default",
@@ -54,6 +55,7 @@ class MigrateSchema(BaseOperator):
         self.project_id = project_id
         self.dataset_id = dataset_id
         self.table_id = table_id
+        self.dag_table_id = dag_table_id
         self.new_schema_fields = new_schema_fields
         self.gcp_conn_id = gcp_conn_id
         self.delegate_to = delegate_to
@@ -62,13 +64,13 @@ class MigrateSchema(BaseOperator):
         self.hook = BigQueryHook(
             gcp_conn_id=self.gcp_conn_id, delegate_to=self.delegate_to
         )
-        conn = self.hook.get_conn()
-        self.cursor = conn.cursor()
+        # conn = self.hook.get_conn()
+        # self.cursor = conn.cursor()
 
     def execute(self, context):
         if not self.new_schema_fields:
             self.new_schema_fields = self.xcom_pull(
-                context=context, task_ids="schema_parsing"
+                context=context, task_ids=f"{self.dag_table_id}.schema_parsing"
             )[f"{self.dataset_id}.{self.table_id}"]
 
         (
